OC.L10N.register(
    "news",
    {
    "News" : "Nyhende",
    "Saved" : "Lagra",
    "Download" : "Last ned",
    "Close" : "Lukk",
    "Language" : "Språk",
    "by" : "av",
    "from" : "frå",
    "Description" : "Skildring",
    "Refresh" : "Oppfrisk",
    "Web address" : "Nettadresse",
    "Folder" : "Mappe",
    "New folder" : "Ny mappe",
    "Folder name" : "Mappenamn",
    "Credentials" : "Credentials",
    "Username" : "Brukarnamn",
    "Password" : "Passord",
    "New Folder" : "Ny mappe",
    "Create" : "Lag",
    "Rename" : "Endra namn",
    "Newest first" : "Nyaste fyrst",
    "Oldest first" : "Eldste fyrst",
    "Delete" : "Ta bort",
    "Dismiss" : "Forkast",
    "Settings" : "Innstillingar",
    "Import" : "Importer",
    "Export" : "Eksporter",
    "Help" : "Hjelp",
    "Keyboard shortcuts" : "Tastatursnarvegar",
    "Documentation" : "Dokumentasjon"
},
"nplurals=2; plural=(n != 1);");
